@@ -6,6 +6,7 @@ from concurrent.futures import ThreadPoolExecutor
 
 import pandas as pd
 from rich.progress import Progress
+from rich.progress import track
 
 from .cas import CAS
 from .config import settings
@@ -46,6 +47,23 @@ class Collect:
                 ]
             )
 
+    async def run_keys(self, keys):
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+        executor = ThreadPoolExecutor(200)
+
+        parallel_docs = asyncio.gather(
+            *[
+                loop.run_in_executor(
+                    executor, functools.partial(self.parallel_docs, doc, cdclass),
+                )
+                for doc, cdclass in track(
+                    keys, description=f"Getting keys in {settings.base}"
+                )
+            ]
+        )
+        loop.run_until_complete(parallel_docs)
+
     def parallel_classes(self, progress, task, cdclass):
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
